# This file was auto-generated by Fern from our API Definition.

from .asset_not_found_error import AssetNotFoundError
from .data_frame_request_out import DataFrameRequestOut
from .data_frame_request_out_columns_item import DataFrameRequestOutColumnsItem
from .data_frame_request_out_data_item_item import DataFrameRequestOutDataItemItem
from .data_frame_request_out_index_item import DataFrameRequestOutIndexItem
from .data_frame_unknown_format_error import DataFrameUnknownFormatError
from .file_too_large_error import FileTooLargeError
from .parent_folder_error import ParentFolderError
from .save_asset_request_out import SaveAssetRequestOut

__all__ = [
    "AssetNotFoundError",
    "DataFrameRequestOut",
    "DataFrameRequestOutColumnsItem",
    "DataFrameRequestOutDataItemItem",
    "DataFrameRequestOutIndexItem",
    "DataFrameUnknownFormatError",
    "FileTooLargeError",
    "ParentFolderError",
    "SaveAssetRequestOut",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.api_error import ApiError


class InternalServerError(ApiError):
    def __init__(self, body: typing.Any):
        super().__init__(status_code=500, body=body)
